import xml.etree.ElementTree as ET
import argparse

class DatParser(object):

    sample_sets = None
    __tree = None
    __filename = None

    def __init__(self, font="Tahoma", size=16):
        self.sample_sets = { }

        self.__tree = None
        self.__filename = None

    @property
    def tree(self):
        if (self.__tree):
            return self.__tree
        if (self.__filename):
            self.__tree = ET.parse(self.__filename)
        
        return self.__tree

    @tree.setter
    def tree(self, filename):
        self.__filename = filename
        self.__tree = None

    def parse(self, filename):
        self.tree = filename

        for game_tag in self.tree.getroot():
            if 'sampleof' in game_tag.attrib:
                game = game_tag.attrib['name']

                if not game_tag.attrib['sampleof'] in self.sample_sets:
                    self.sample_sets[game_tag.attrib['sampleof']] = []

                for rom_tag in game_tag:
                    if rom_tag.tag == 'sample':
                        if not rom_tag.attrib['name'] in self.sample_sets[game_tag.attrib['sampleof']]:
                            self.sample_sets[game_tag.attrib['sampleof']].append(rom_tag.attrib['name'])

    def print(self):
        for name, samples in self.sample_sets.items():
            print('{s}.zip:'.format(s=name))
            for sample in samples:
                print('    {s}.wav'.format(s=sample))
            print()


if __name__ == '__main__':

    parser = argparse.ArgumentParser(description='build a list of required samples from a dat file')
    parser.add_argument('input', help='dat file to parse')

    arguments = parser.parse_args()

    datparser = DatParser()
    datparser.parse(arguments.input)
    datparser.print()
